@@ -248,7 +248,7 @@ sub MY::postamble {
     $MAKEFILEPL,
     'Other', 'Other.pm', qq{},
     <<'EOF',
-SKIP   => [qw(all static dynamic )],
+SKIP   => [qw(all static dynamic)],
 clean  => {'FILES' => 'libparser$(LIB_EXT)'},
 EOF
   ) . <<'EOF',
@@ -293,6 +293,29 @@ EOF
 };
 virtual_rename('subdirsskip', 'Other/lib/file.c', 'Other/file.c');
 
+# to mimic behaviour of Math-CDF version 0.1
+$label2files{subdirsskip2} = +{
+  %{ $label2files{subdirsskip} }, # make copy
+  'Other/Makefile.PL' => sprintf(
+    $MAKEFILEPL,
+    'Other', 'Other.pm', qq{},
+    <<'EOF',
+SKIP   => [qw(all static static_lib dynamic dynamic_lib test_dynamic test)],
+clean  => {'FILES' => 'libparser$(LIB_EXT)'},
+EOF
+  ) . <<'EOF',
+sub MY::top_targets {
+  my ($self) = @_;
+  <<'SNIP' . $self->static_lib_pure_cmd('$(O_FILES)');
+test ::
+all :: static
+static :: libparser$(LIB_EXT)
+libparser$(LIB_EXT): $(O_FILES)
+SNIP
+}
+EOF
+};
+
 my $XS_MULTI = $XS_OTHER;
 # check compiling from top dir still can include local
 $XS_MULTI =~ s:(#include "XSUB.h"):$1\n#include "header.h":;
@@ -321,7 +344,7 @@ delete $label2files{bscodemulti}->{'t/is_odd.t'};
 $label2files{staticmulti} = +{
   %{ $label2files{'multi'} }, # make copy
   'Makefile.PL' => sprintf(
-    $MAKEFILEPL, 'Test', 'lib/XS/Test.pm', qq{'$typemap'},
+    $MAKEFILEPL, 'Test', 'lib/XS/Test.pm', qq{},
     q{LINKTYPE => 'static', XSMULTI => 1,},
   ),
 };
@@ -329,7 +352,7 @@ $label2files{staticmulti} = +{
 $label2files{xsbuild} = +{
   %{ $label2files{'multi'} }, # make copy
   'Makefile.PL' => sprintf(
-    $MAKEFILEPL, 'Test', 'lib/XS/Test.pm', qq{'$typemap'},
+    $MAKEFILEPL, 'Test', 'lib/XS/Test.pm', qq{},
     q{
       XSMULTI => 1,
       XSBUILD => {
@@ -425,11 +448,13 @@ sub list_dynamic {
     ) : (),
     [ 'xsbuild', '', '' ],
     [ 'subdirsskip', '', '' ],
+    [ 'subdirsskip2', '', '' ],
   );
 }
 
+my $held_dir = undef;
 sub run_tests {
-  my ($perl, $label, $add_target, $add_testtarget) = @_;
+  my ($perl, $label, $add_target, $add_testtarget, $hold_dir) = @_;
   my $sublabel = $add_target;
   $sublabel =~ s#[\s=]##g;
   ok( my $dir = setup_xs($label, $sublabel), "setup $label$sublabel" );
@@ -483,6 +508,14 @@ sub run_tests {
   chdir File::Spec->updir or die;
   if ($ENV{EUMM_KEEP_TESTDIRS}) {
     ok 1, "don't teardown $dir";
+    return;
+  }
+  if (defined $held_dir) {
+    ok rmtree($held_dir), "belated teardown $held_dir";
+    $held_dir = undef;
+  }
+  if ($hold_dir) {
+    $held_dir = $dir;
   } else {
     ok rmtree($dir), "teardown $dir";
   }
